@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AbstractFromMeta;
 
-our $DATE = '2014-12-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-07-07'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,14 +22,26 @@ use Data::Dump qw(dump);
 use File::Slurp::Tiny qw(read_file);
 use File::Spec::Functions qw(catfile);
 
+# either provide filename or filecontent
 sub _get_from_module {
-    my ($self, $filename) = @_;
+    my ($self, $filename, $filecontent) = @_;
 
-    (my $mod_p = $filename) =~ s!^lib/!!;
-    require $mod_p;
+    my $pkg;
+    if ($filename) {
+        (my $mod_p = $filename) =~ s!^lib/!!;
+        require $mod_p;
 
-    # find out the package of the file
-    (my $pkg = $mod_p) =~ s/\.pm\z//; $pkg =~ s!/!::!g;
+        # find out the package of the file
+        ($pkg = $mod_p) =~ s/\.pm\z//; $pkg =~ s!/!::!g;
+    } else {
+        eval $filecontent;
+        die if $@;
+        if ($filecontent =~ /\bpackage\s+(\w+(?:::\w+)*)/s) {
+            $pkg = $1;
+        } else {
+            die "Can't extract package name from file content";
+        }
+    }
 
     no strict 'refs';
     my $metas = \%{"$pkg\::SPEC"};
@@ -69,13 +81,23 @@ sub _get_from_module {
     return $abstract;
 }
 
+# either provide filename or filecontent
 sub _get_from_script {
-    my ($self, $filename) = @_;
+    require File::Temp;
+
+    my ($self, $filename, $filecontent) = @_;
 
     # check if script uses Perinci::CmdLine
-    my $ct = read_file $filename;
-    unless ($ct =~ /\b(?:use|require)\s+
-                    (Perinci::CmdLine(?:::Lite|::Any)?)\b/x) {
+    if ($filename) {
+        $filecontent = read_file $filename;
+    } else {
+        # we need an actual file later when we feed to pericmd dumper
+        require File::Temp;
+        (undef, $filename) = File::Temp::tempfile();
+    }
+
+    unless ($filecontent =~ /\b(?:use|require)\s+
+                             (Perinci::CmdLine(?:::Lite|::Any)?)\b/x) {
         return undef;
     }
 
@@ -127,19 +149,22 @@ sub _get_from_script {
     return $meta->{summary};
 }
 
+# either provide filename or filecontent
 sub _get_abstract_from_meta {
-    my ($self, $filename) = @_;
+    my ($self, $filename, $filecontent) = @_;
 
     local @INC = @INC;
     unshift @INC, 'lib';
 
-    my $content = do {
-        open my($fh), "<", $filename or die "Can't open $filename: $!";
-        local $/;
-        ~~<$fh>;
-    };
+    if ($filename) {
+        $filecontent = do {
+            open my($fh), "<", $filename or die "Can't open $filename: $!";
+            local $/;
+            ~~<$fh>;
+        };
+    }
 
-    unless ($content =~ m{^#[ \t]*ABSTRACT:[ \t]*([^\n]*)[ \t]*$}m) {
+    unless ($filecontent =~ m{^#[ \t]*ABSTRACT:[ \t]*([^\n]*)[ \t]*$}m) {
         $self->log_debug(["Skipping %s: no # ABSTRACT", $filename]);
         return undef;
     }
@@ -195,7 +220,7 @@ sub munge_file {
         return;
     }
 
-    my $abstract = $self->_get_abstract_from_meta($file->name);
+    my $abstract = $self->_get_abstract_from_meta(undef, $file->content);
     unless (defined $abstract) {
         die "Can't figure out abstract for " . $file->name;
     }
@@ -222,7 +247,7 @@ Dist::Zilla::Plugin::Rinci::AbstractFromMeta - Fill out abstract from Rinci meta
 
 =head1 VERSION
 
-This document describes version 0.06 of Dist::Zilla::Plugin::Rinci::AbstractFromMeta (from Perl distribution Dist-Zilla-Plugin-Rinci-AbstractFromMeta), released on 2014-12-17.
+This document describes version 0.07 of Dist::Zilla::Plugin::Rinci::AbstractFromMeta (from Perl distribution Dist-Zilla-Plugin-Rinci-AbstractFromMeta), released on 2015-07-07.
 
 =head1 SYNOPSIS
 
@@ -273,7 +298,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
